@@ -25,22 +25,3 @@ def crawl(list_user,args):
         if not es.is_crawled(user):
             request_twint.get_info_from_user.delay(user,args_copy)
 
-@app.task
-def crawl_from_search (args):
-    signal.signal(signal.SIGINT, exit_)
-    signal.signal(signal.SIGTERM, exit_)
-
-
-def exit_():
-    global stop
-    stop = True
-
-
-if __name__ == '__main__':
-    args = {}
-    args["search"] = "(#Covid-19)"
-    args["limit"] = 1000
-    args["follow_limit"] = 10
-    args["tweet_interact"] = 1
-    args["tweet"] = 0
-    crawl_from_search(args)
