@@ -11,21 +11,7 @@ from TrollHunter.twitter_crawler.twint import twint
 HIDE_TWEET_OUPUT = True
 elastic = Elastic()
 
-"""
-args:
-    tweet:          set to 0 to avoid tweet (default: 1)
-    follow:         set to 0 to avoid follow (default: 1)
-    limit:          set the number of tweet to retrieve (Increments of 20, default: 100)
-    follow_limit:   set the number of following and followers to retrieve (default: 100)
-    since:          date selector for tweets (Example: 2017-12-27)
-    until:          date selector for tweets (Example: 2017-12-27)
-    retweet:        set to 1 to retrieve retweet (default: 0)
-    search:         search terms format for hastag : (#hashtag)
-    tweet_interact: set to 1 to parse tweet interaction between users (default: 0)
-    depth:          search tweet and info from list of follow
-    
-TODO: Retrieve tweet twitted to the user ?
-"""
+
 @app.task
 def get_info_from_user(username, args):
     reset_data()
@@ -127,6 +113,16 @@ def get_tweet_from_user(user, args):
     user.set_tweets(twint.output.tweets_list)
     return user.tweets
 
+@app.task
+def get_interaction_from_crawl(tweet,args):
+
+    user = User(tweet["username"])
+    user.set_tweets([tweet])
+    get_info_user(user, args)
+    retrieve_tweet_actors(user, args)
+    elastic.store_user(user.user_info)
+    elastic.store_interactions(user.interactions)
+
 
 @app.task
 def get_tweet_from_search(args):
@@ -139,9 +135,9 @@ def get_tweet_from_search(args):
     twint.run.Search(config)
     tweet_result = twint.output.tweets_list
     for tweet in tweet_result:
-        get_info_from_user.delay(tweet.username,args)
+        get_interaction_from_crawl.delay(vars(tweet),args)
+        # get_info_from_crawl.delay(tweet.username,args)
     elastic.store_tweets(tweet_result)
-    return format_tweet_to_html(tweet_result, "test")
 
 def crawl_tweet(args):
     reset_data()
@@ -179,7 +175,7 @@ def get_origin_tweet(args):
 
     return format_tweet_to_html(res, "ORIGIN")
 
-
+# Config for research twint
 def get_twint_config(args, user=None):
     config = twint.Config()
     config.Hide_output = HIDE_TWEET_OUPUT
